summaryrefslogtreecommitdiff
path: root/usr.bin/rsync/receiver.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/rsync/receiver.c')
-rw-r--r--usr.bin/rsync/receiver.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.bin/rsync/receiver.c b/usr.bin/rsync/receiver.c
index 935432beb58..93ec4cb3fc5 100644
--- a/usr.bin/rsync/receiver.c
+++ b/usr.bin/rsync/receiver.c
@@ -1,4 +1,4 @@
-/* $Id: receiver.c,v 1.11 2019/02/16 05:30:28 deraadt Exp $ */
+/* $Id: receiver.c,v 1.12 2019/02/16 10:44:01 florian Exp $ */
/*
* Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -92,8 +92,8 @@ rsync_set_metadata(struct sess *sess, int newfile,
}
/*
* Pledges: unveil, rpath, cpath, wpath, stdio, fattr.
* Pledges (dry-run): -cpath, -wpath, -fattr.
*/
int
rsync_receiver(struct sess *sess, int fdin, int fdout, const char *root)
@@ -108,7 +108,7 @@ rsync_receiver(struct sess *sess, int fdin, int fdout, const char *root)
struct upload *ul = NULL;
mode_t oumask;
- if (pledge("stdio rpath wpath cpath fattr getpw unveil", NULL) == -1) {
+ if (pledge("stdio rpath wpath cpath fattr chown getpw unveil", NULL) == -1) {
ERR(sess, "pledge");
goto out;
}
@@ -92,8 +92,8 @@ rsync_set_metadata(struct sess *sess, int newfile,
}
/*
- * Pledges: unveil, rpath, cpath, wpath, stdio, fattr.
- * Pledges (dry-run): -cpath, -wpath, -fattr.
+ * Pledges: unveil, rpath, cpath, wpath, stdio, fattr, chown.
+ * Pledges (dry-run): -cpath, -wpath, -fattr, -chown.
*/
int